@@ -15,7 +15,7 @@ our @ISA = qw(DynaLoader);
 # SQL_DRIVER_VER is formatted as dd.dd.dddd
 # for version 5.x please switch to 5.00(_00) version numbering
 # keep $VERSION in Bundle/DBD/mysql.pm in sync
-our $VERSION = '4.032';
+our $VERSION = '4.034';
 
 bootstrap DBD::mysql $VERSION;
 
@@ -1048,7 +1048,13 @@ But now for a more formal approach:
 
     $dbh = DBI->connect($dsn, $user, $password);
 
-A C<database> must always be specified.
+The C<database> is not a required attribute, but please note that MySQL
+has no such thing as a default database. If you don't specify the database
+at connection time your active database will be null and you'd need to prefix
+your tables with the database name; i.e. 'SELECT * FROM mydb.mytable'.
+
+This is similar to the behavior of the mysql command line client. Also,
+'SELECT DATABASE()' will return the current database active for the handle.
 
 =over
 
@@ -1069,6 +1075,12 @@ separated by a colon ( C<:> ) character or by using the  C<port> argument.
 To connect to a MySQL server on localhost using TCP/IP, you must specify the
 hostname as 127.0.0.1 (with the optional port).
 
+When connecting to a MySQL Server with IPv6, a bracketed IPv6 address should be used.
+Example DSN:
+
+  my $dsn = "DBI:mysql:;host=[1a12:2800:6f2:85::f20:8cf];port=3306";
+
+
 =item mysql_client_found_rows
 
 Enables (TRUE value) or disables (FALSE value) the flag CLIENT_FOUND_ROWS
@@ -1172,6 +1184,10 @@ database:
 
 This means that your communication with the server will be encrypted.
 
+Please note that this can only work if you enabled SSL when compiling
+DBD::mysql; this is the default starting version 4.034.
+See L<DBD::mysql::INSTALL> for more details.
+
 If you turn mysql_ssl on, you might also wish to use the following
 flags:
 
@@ -1205,23 +1221,15 @@ problems if server-side prepared statements are also enabled.
 
 =item Prepared statement support (server side prepare)
 
-As of 3.0002_1, server side prepare statements were on by default (if your
-server was >= 4.1.3). As of 3.0009, they were off by default again due to
-issues with the prepared statement API (all other mysql connectors are
-set this way until C API issues are resolved). The requirement to use
-prepared statements still remains that you have a server >= 4.1.3
-
 To use server side prepared statements, all you need to do is set the variable
 mysql_server_prepare in the connect:
 
-$dbh = DBI->connect(
-                    "DBI:mysql:database=test;host=localhost;mysql_server_prepare=1",
-                    "",
-                    "",
-                    { RaiseError => 1, AutoCommit => 1 }
-                    );
-
-* Note: delimiter for this param is ';'
+  $dbh = DBI->connect(
+    "DBI:mysql:database=test;host=localhost;mysql_server_prepare=1",
+    "",
+    "",
+    { RaiseError => 1, AutoCommit => 1 }
+  );
 
 There are many benefits to using server side prepare statements, mostly if you are
 performing many inserts because of that fact that a single statement is prepared
@@ -1230,7 +1238,7 @@ to accept multiple insert values.
 To make sure that the 'make test' step tests whether server prepare works, you just
 need to export the env variable MYSQL_SERVER_PREPARE:
 
-export MYSQL_SERVER_PREPARE=1
+  export MYSQL_SERVER_PREPARE=1
 
 
 =item mysql_embedded_options
@@ -1240,9 +1248,9 @@ options to embedded server.
 
 Example:
 
-use DBI;
-$testdsn="DBI:mysqlEmb:database=test;mysql_embedded_options=--help,--verbose";
-$dbh = DBI->connect($testdsn,"a","b");
+  use DBI;
+  $testdsn="DBI:mysqlEmb:database=test;mysql_embedded_options=--help,--verbose";
+  $dbh = DBI->connect($testdsn,"a","b");
 
 This would cause the command line help to the embedded MySQL server library
 to be printed.
@@ -1256,81 +1264,89 @@ If not specified [server] and [embedded] groups will be used.
 
 Example:
 
-$testdsn="DBI:mysqlEmb:database=test;mysql_embedded_groups=embedded_server,common";
+  $testdsn="DBI:mysqlEmb:database=test;mysql_embedded_groups=embedded_server,common";
 
 =item mysql_conn_attrs
 
 The option <mysql_conn_attrs> is a hash of attribute names and values which can be
-used to send custom connection attributes to the server.
+used to send custom connection attributes to the server. Some attributes like
+'_os', '_platform', '_client_name' and '_client_version' are added by libmysqlclient
+and 'program_name' is added by DBD::mysql.
 
- node1$ cat ./foo.pl
- #!/usr/bin/perl
+You can then later read these attributes from the performance schema tables which
+can be quite helpful for profiling your database or creating statistics.
+You'll have to use a MySQL 5.6 server and libmysqlclient or newer to leverage this
+feature.
 
- use DBI;
- use Data::Dumper;
+  my $dbh= DBI->connect($dsn, $user, $password,
+    { AutoCommit => 0,
+      mysql_conn_attrs => {
+        foo => 'bar',
+        wiz => 'bang'
+      },
+    });
 
- my ($test_dsn, $test_user, $test_password) = ($ARGV[0], $ARGV[1], $ARGV[2]);
+Now you can select the results from the performance schema tables. You can do this
+in the same session, but also afterwards. It can be very useful to answer questions
+like 'which script sent this query?'.
 
- my $dbh= DBI->connect($test_dsn, $test_user, $test_password,
-     { AutoCommit => 0,
-       mysql_conn_attrs => { foo => 'bar', wiz => 'bang' },
-     });
+  my $results = $dbh->selectall_hashref(
+    'SELECT * FROM performance_schema.session_connect_attrs',
+    'ATTR_NAME'
+  );
 
- my $results = $dbh->selectall_hashref('SELECT * FROM performance_schema.session_connect_attrs', 'ATTR_NAME');
- print Dumper($results);
+This returns:
 
- $dbh->disconnect();
- node1$ perl ./foo.pl 'DBI:mysql:test;hostname=127.0.0.1;port=5624' msandbox msandbox
- $VAR1 = {
-           'program_name' => {
-                               'ATTR_VALUE' => './foo.pl',
-                               'PROCESSLIST_ID' => '3',
-                               'ATTR_NAME' => 'program_name',
-                               'ORDINAL_POSITION' => '5'
-                             },
-           '_os' => {
-                      'ATTR_VALUE' => 'osx10.8',
-                      'PROCESSLIST_ID' => '3',
-                      'ATTR_NAME' => '_os',
-                      'ORDINAL_POSITION' => '0'
-                    },
-           'wiz' => {
-                      'ATTR_VALUE' => 'bang',
-                      'PROCESSLIST_ID' => '3',
-                      'ATTR_NAME' => 'wiz',
-                      'ORDINAL_POSITION' => '3'
-                    },
-           '_platform' => {
-                            'ATTR_VALUE' => 'x86_64',
-                            'PROCESSLIST_ID' => '3',
-                            'ATTR_NAME' => '_platform',
-                            'ORDINAL_POSITION' => '4'
-                          },
-           '_client_name' => {
-                               'ATTR_VALUE' => 'libmysql',
-                               'PROCESSLIST_ID' => '3',
-                               'ATTR_NAME' => '_client_name',
-                               'ORDINAL_POSITION' => '1'
-                             },
-           '_pid' => {
-                       'ATTR_VALUE' => '59860',
-                       'PROCESSLIST_ID' => '3',
-                       'ATTR_NAME' => '_pid',
-                       'ORDINAL_POSITION' => '2'
-                     },
-           'foo' => {
-                      'ATTR_VALUE' => 'bar',
-                      'PROCESSLIST_ID' => '3',
-                      'ATTR_NAME' => 'foo',
-                      'ORDINAL_POSITION' => '6'
-                    },
-           '_client_version' => {
-                                  'ATTR_VALUE' => '5.6.24',
-                                  'PROCESSLIST_ID' => '3',
-                                  'ATTR_NAME' => '_client_version',
-                                  'ORDINAL_POSITION' => '7'
-                                }
-         };
+  $result = {
+    'foo' => {
+        'ATTR_VALUE'       => 'bar',
+        'PROCESSLIST_ID'   => '3',
+        'ATTR_NAME'        => 'foo',
+        'ORDINAL_POSITION' => '6'
+    },
+    'wiz' => {
+        'ATTR_VALUE'       => 'bang',
+        'PROCESSLIST_ID'   => '3',
+        'ATTR_NAME'        => 'wiz',
+        'ORDINAL_POSITION' => '3'
+    },
+    'program_name' => {
+        'ATTR_VALUE'       => './foo.pl',
+        'PROCESSLIST_ID'   => '3',
+        'ATTR_NAME'        => 'program_name',
+        'ORDINAL_POSITION' => '5'
+    },
+    '_client_name' => {
+        'ATTR_VALUE'       => 'libmysql',
+        'PROCESSLIST_ID'   => '3',
+        'ATTR_NAME'        => '_client_name',
+        'ORDINAL_POSITION' => '1'
+    },
+    '_client_version' => {
+        'ATTR_VALUE'       => '5.6.24',
+        'PROCESSLIST_ID'   => '3',
+        'ATTR_NAME'        => '_client_version',
+        'ORDINAL_POSITION' => '7'
+    },
+    '_os' => {
+        'ATTR_VALUE'       => 'osx10.8',
+        'PROCESSLIST_ID'   => '3',
+        'ATTR_NAME'        => '_os',
+        'ORDINAL_POSITION' => '0'
+    },
+    '_pid' => {
+        'ATTR_VALUE'       => '59860',
+        'PROCESSLIST_ID'   => '3',
+        'ATTR_NAME'        => '_pid',
+        'ORDINAL_POSITION' => '2'
+    },
+    '_platform' => {
+        'ATTR_VALUE'       => 'x86_64',
+        'PROCESSLIST_ID'   => '3',
+        'ATTR_NAME'        => '_platform',
+        'ORDINAL_POSITION' => '4'
+    }
+  };
 
 =back
 
@@ -1546,16 +1562,15 @@ stored in the database are utf8.  This feature defaults to off.
 When set, a data retrieved from a textual column type (char, varchar,
 etc) will have the UTF-8 flag turned on if necessary.  This enables
 character semantics on that string.  You will also need to ensure that
-your database / table / column is configured to use UTF8.  See Chapter
-10 of the mysql manual for details.
+your database / table / column is configured to use UTF8. See for more
+information the chapter on character set support in the MySQL manual:
+L<http://dev.mysql.com/doc/refman/5.7/en/charset.html>
 
 Additionally, turning on this flag tells MySQL that incoming data should
 be treated as UTF-8.  This will only take effect if used as part of the
 call to connect().  If you turn the flag on after connecting, you will
 need to issue the command C<SET NAMES utf8> to get the same effect.
 
-This option is experimental and may change in future versions.
-
 =item mysql_enable_utf8mb4
 
 This is similar to mysql_enable_utf8, but is capable of handling 4-byte
@@ -1591,7 +1606,7 @@ use the index:
              rows: 1
             Extra: Using index condition
     1 row in set (0.00 sec)
-    
+
     MariaDB [test]> explain select * from test where value0 = 3
         -> \G
     *************************** 1. row ***************************
@@ -1938,13 +1953,10 @@ An example would be:
     }
   } until (!$sth->more_results)
 
-For more examples, please see the eg/ directory. This is where helpful
-DBD::mysql code snippets will be added in the future.
-
 =head2 Issues with multiple result sets
 
-Please be aware ther could be issues if your result sets are "jagged",
-meaning the number of columns of your results vary. Varying numbers of 
+Please be aware there could be issues if your result sets are "jagged",
+meaning the number of columns of your results vary. Varying numbers of
 columns could result in your script crashing.
 
 
@@ -2018,7 +2030,7 @@ support).
 For the past nine years DBD::mysql has been maintained by
 Patrick Galbraith (I<patg@patg.net>), and recently with the great help of
 Michiel Beijen (I<michiel.beijen@gmail.com>),  along with the entire community
-of Perl developers who keep sending patches to help continue improving DBD::mysql 
+of Perl developers who keep sending patches to help continue improving DBD::mysql
 
 
 =head1 CONTRIBUTIONS
